package com.example.witsystem_device_plugin;

import android.bluetooth.BluetoothDevice;
import android.content.Context;
import android.os.Handler;
import android.util.Log;

import androidx.annotation.NonNull;

import com.alibaba.fastjson.JSON;
import com.example.witsystem_device_plugin.SDK.channel.ChannelName;
import com.example.witsystem_device_plugin.SDK.context.FlutterContext;
import com.example.witsystem_device_plugin.SDK.InitSDK;
import com.example.witsystem_device_plugin.SDK.entity.BleAddMarkResult;
import com.example.witsystem_device_plugin.SDK.event.AddDeviceHandler;
import com.example.witsystem_device_plugin.SDK.event.BleAddMarkHandler;
import com.witsystem.top.witsystem_android_ble_sdk.device.Manage.DeviceFunctionType;
import com.witsystem.top.witsystem_android_ble_sdk.device.Manage.DeviceManage;
import com.witsystem.top.witsystem_android_ble_sdk.device.WitsystemSDK;
import com.witsystem.top.witsystem_android_ble_sdk.device.call.BleCallBack;
import com.witsystem.top.witsystem_android_ble_sdk.device.call.BleProgressCommandCall;
import com.witsystem.top.witsystem_android_ble_sdk.device.call.BleSendCommandCall;
import com.witsystem.top.witsystem_android_ble_sdk.device.call.BleUnlockCallBack;
import com.witsystem.top.witsystem_android_ble_sdk.device.command.CardType;
import com.witsystem.top.witsystem_android_ble_sdk.device.command.CommandMessage;
import com.witsystem.top.witsystem_android_ble_sdk.device.command.FaceType;
import com.witsystem.top.witsystem_android_ble_sdk.device.command.MarkType;
import com.witsystem.top.witsystem_android_ble_sdk.device.command.PasswordType;
import com.witsystem.top.witsystem_android_ble_sdk.error.BluetoothIsNotOn;
import com.witsystem.top.witsystem_android_ble_sdk.error.BluetoothNotSupported;
import com.witsystem.top.witsystem_android_ble_sdk.error.DeviceErrorCode;
import com.witsystem.top.witsystem_android_ble_sdk.error.GpsNotOpen;
import com.witsystem.top.witsystem_android_ble_sdk.error.LessPermissions;
import com.witsystem.top.witsystem_android_ble_sdk.util.ByteToString;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeoutException;

import SDK.err.Error;
import SDK.model.Devices;
import SDK.net.NetResponse;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * WitsystemDevicePlugin
 */
public class WitsystemDevicePlugin implements FlutterPlugin, MethodCallHandler {
    private static final String TAG = "插件SDK";

    private MethodChannel channel;
    private Context applicationContext;
    private WitsystemSDK witsystmBleSDK;

    private final AddDeviceHandler addDeviceHandler = new AddDeviceHandler();

    private final BleAddMarkHandler bleAddMarkHandler = new BleAddMarkHandler();

    // private final ExecutorService executorService = Executors.newSingleThreadExecutor();

    private final Handler handler = new Handler();

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        applicationContext = flutterPluginBinding.getApplicationContext();
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), ChannelName.witsystemSDK);
        channel.setMethodCallHandler(this);

        EventChannel scanningChannel = new EventChannel(flutterPluginBinding.getBinaryMessenger(), ChannelName.multipleAddDevice);
        scanningChannel.setStreamHandler(addDeviceHandler);

        EventChannel bleAddMarkChannel = new EventChannel(flutterPluginBinding.getBinaryMessenger(), ChannelName.bleAddMark);
        bleAddMarkChannel.setStreamHandler(bleAddMarkHandler);
    }


    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

        switch (call.method) {

            case "initSDK":
                witsystmBleSDK = new FlutterContext<WitsystemSDK>(applicationContext, result).exe(new InitSDK(call.argument("appId"), call.argument("token"), call.argument("appSecret"), call.argument("rsaPrivateKey")));
                return;
            case "bleUnlock":
                bleUnlock(call.argument("deviceId"), result);
                return;
            case "scanAddBleDevice":
                startAddScan();
                break;
            case "stopAddBleDevice":
                stopAddBleDevice();
                break;
            case "addBleDevice":
                addBleDevice(call.argument("deviceId"), call.argument("DeviceName"), result);
                return;
            case "closeAddDevice":
                closeAddDevice(call.argument("deviceId"), result);
                return;
            case "addPassword":
                addPassword(call.argument("deviceId"), call.argument("passwordType"), call.argument("password"), call.argument("passwordName"), call.argument("userId"), result);
                return;
            case "deletePassword":
                deletePassword(call.argument("deviceId"), call.argument("uid"), result);
                return;
            case "addCard":
                addCard(call.argument("deviceId"), call.argument("cardType"), call.argument("cardName"), call.argument("userId"), result);
                return;
            case "cancelAddCard":
                cancelAddCard(call.argument("deviceId"));
                break;
            case "deleteCard":
                deleteCard(call.argument("deviceId"), call.argument("uid"), result);
                return;
            case "freezeCard":
                freezeCard(call.argument("deviceId"), call.argument("uid"), Boolean.parseBoolean(call.argument("isFreeze")), result);
                return;
            case "closeOrOpenCard":
                closeOrOpenCard(call.argument("deviceId"), Boolean.parseBoolean(call.argument("isFreeze")), result);
                return;
            case "addMark":
                addMark(call.argument("deviceId"), call.argument("markType"), call.argument("markName"), call.argument("userId"));
                break;
            case "cancelAddMark":
                cancelAddMark(call.argument("deviceId"));
                break;
            case "deleteMark":
                deleteMark(call.argument("deviceId"), call.argument("uid"), result);
                return;
            case "freezeMark":
                freezeMark(call.argument("deviceId"), call.argument("uid"), Boolean.parseBoolean(call.argument("isFreeze")), result);
                return;
            case "addFace":
                addFace(call.argument("deviceId"), call.argument("faceType"), call.argument("faceName"), call.argument("userId"), result);
                break;
            case "cancelAddFace":
                cancelAddFace(call.argument("deviceId"));
                break;
            case "deleteFace":
                deleteFace(call.argument("deviceId"), call.argument("uid"), result);
                return;
            case "freezeFace":
                freezeFace(call.argument("deviceId"), call.argument("uid"), Boolean.parseBoolean(call.argument("isFreeze")), result);
                return;
            case "updateVolume":
                updateVolume(call.argument("deviceId"), call.argument("volume"), result);
                return;
            case "updateDeviceState":
                updateDeviceState(call.argument("deviceId"), result);
                return;
            case "closeBleDevice":
                closeBleDevice(call.argument("deviceId"));
                break;
            case "deviceList":
                deviceList(result);
                return;
            case "device":
                device(call.argument("deviceId"), result);
                return;
            case "isDeviceFunction"://查询指定设置是否支持指定的功能
                boolean deviceFunction = witsystmBleSDK.getDeviceManage().isDeviceFunction(call.argument("deviceId"), Enum.valueOf(DeviceFunctionType.class, call.argument("type")));
                result.success(deviceFunction);
                return;
            case "deviceUserList":
                deviceUserList(call.argument("deviceId"), result);
                return;
            case "freezeOrUnfreeze":
                freezeOrUnfreeze(call.argument("deviceId"), call.argument("freezeUserUuid"), call.argument("isFreeze"), result);
                return;
            case "manageDeleteDeviceUser":
                manageDeleteDeviceUser(call.argument("deviceId"), call.argument("deleteUserUuid"), result);
                return;
            case "sendDevice":
                sendDevice(call.argument("userId"), call.argument("deviceId"), call.argument("startDate"), call.argument("endDate"), call.argument("authType"), call.argument("repeatType"), result);
                return;
            case "transferDevice":
                transferDevice(call.argument("userId"), call.argument("deviceId"), result);
                return;
            case "deleteDevices":
                deleteDevices(call.argument("deviceId"), result);
                return;
            case "lockRecord":
                lockRecord(call.argument("deviceId"), call.argument("page"), result);
                return;
            default:
                result.notImplemented();
                break;
        }
        result.success("SUCCESS");
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
    /*-------------------------------- 设备的蓝牙操作------------------------------*/

    /**
     * 启动添加扫描
     */
    private void startAddScan() {
        try {
            witsystmBleSDK.getAddDevice().scanAddBleDevice((bluetoothDevice, i, bytes) -> {
                Map<String, Object> map = new HashMap<>();
                map.put("address", bluetoothDevice.getAddress());
                map.put("deviceId", bluetoothDevice.getName());
                map.put("rssi", i);
                map.put("bytes", ByteToString.bytesToHexString(bytes));
                handler.post(() -> addDeviceHandler.onScanResult(map));
            });
        } catch (BluetoothNotSupported e) {
            addDeviceHandler.onError(e.getCode(), e.getMessage(), e);
        } catch (BluetoothIsNotOn e) {
            addDeviceHandler.onError(e.getCode(), e.getMessage(), e);
        } catch (LessPermissions e) {
            addDeviceHandler.onError(e.getCode(), e.getMessage(), e);
        } catch (GpsNotOpen e) {
            addDeviceHandler.onError(e.getCode(), e.getMessage(), e);
        }
    }


    /**
     * 停止添加扫描
     */
    private void stopAddBleDevice() {
        try {
            witsystmBleSDK.getAddDevice().stopAddBleDevice();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    /**
     * 添加设备
     */
    private void addBleDevice(String deviceId, String deviceName, Result result) {
        try {
            witsystmBleSDK.getAddDevice().addBleDevice(deviceId, deviceName, new BleCallBack<Devices>() {
                @Override
                public void success(Devices devices) {
                    result.success(JSON.toJSONString(devices));
                }

                @Override
                public void fail(int i, String s) {
                    result.error(String.valueOf(i), s, null);
                }
            });
        } catch (BluetoothNotSupported e) {
            result.error(String.valueOf(e.getCode()), e.getMessage(), JSON.toJSONString(e));
        } catch (InterruptedException e) {
            result.error(String.valueOf(DeviceErrorCode.INTERRUPTED_EXCEPTION.getCode()), DeviceErrorCode.INTERRUPTED_EXCEPTION.getError(), JSON.toJSONString(e));
        } catch (ExecutionException e) {
            result.error(String.valueOf(DeviceErrorCode.EXECUTION_EXCEPTION.getCode()), DeviceErrorCode.EXECUTION_EXCEPTION.getError(), JSON.toJSONString(e));
        } catch (TimeoutException e) {
            result.error(String.valueOf(DeviceErrorCode.TIMEOUT_EXCEPTION.getCode()), DeviceErrorCode.TIMEOUT_EXCEPTION.getError(), JSON.toJSONString(e));
        }
    }

    /**
     * 关闭添加设备
     *
     * @param deviceId 设备ID
     */
    private void closeAddDevice(String deviceId, Result result) {
        try {
            witsystmBleSDK.getAddDevice().closeAddDevice(deviceId);
            result.success("SUCCESS");
        } catch (BluetoothNotSupported e) {
            result.error(String.valueOf(e.getCode()), e.getMessage(), JSON.toJSONString(e));
        }
    }


    /**
     * 开启设备
     */
    private void bleUnlock(String deviceId, Result result) {
        try {
            BleUnlockCallBack<Devices> bleUnlockCallBack = new BleUnlockCallBack<Devices>() {
                @Override
                public void success(Devices devices) {
                    Map<String, Object> map = new HashMap<>();
                    List<Devices> listDevice = new ArrayList<>(1);
                    listDevice.add(devices);
                    map.put("type", "UNLOCK");
                    map.put("devices", listDevice);
                    result.success(JSON.toJSONString(map));
                }

                @Override
                public void fail(int i, String s) {
                    result.error(String.valueOf(i), s, null);
                }

                @Override
                public void foundMultipleDevices(List<BluetoothDevice> list) {
                    Log.i(TAG, "foundMultipleDevices: 扫描到多个设备" + list.size());
                    List<Devices> listDevice = new ArrayList<>();
                    for (BluetoothDevice bluetoothDevice : list) {
                        listDevice.add(DeviceManage.getInstance(null, null).device(bluetoothDevice.getName()));
                    }
                    Map<String, Object> map = new HashMap<>();
                    map.put("type", "DEVICES");
                    map.put("devices", listDevice);
                    result.success(JSON.toJSONString(map));
                }
            };
            if (deviceId == null) {
                witsystmBleSDK.getUnlock().bleUnlock(bleUnlockCallBack);
            } else {
                witsystmBleSDK.getUnlock().bleUnlock(deviceId, bleUnlockCallBack);
            }
        } catch (BluetoothNotSupported e) {
            result.error(String.valueOf(e.getCode()), e.getMessage(), JSON.toJSONString(e));
        } catch (BluetoothIsNotOn e) {
            result.error(String.valueOf(e.getCode()), e.getMessage(), JSON.toJSONString(e));
        } catch (GpsNotOpen e) {
            result.error(String.valueOf(e.getCode()), e.getMessage(), JSON.toJSONString(e));
        } catch (LessPermissions e) {
            result.error(String.valueOf(e.getCode()), e.getMessage(), JSON.toJSONString(e));
        }
    }


    /**
     * 通过蓝牙添加密码
     */
    private void addPassword(String deviceId, String passwordType, String password, String passwordName, String userId, Result result) {
        witsystmBleSDK.getBleDevice().addPassword(deviceId, Enum.valueOf(PasswordType.class, passwordType), password, passwordName, userId, call(result));
    }


    /**
     * 通过蓝牙删除密码
     */
    private void deletePassword(String deviceId, String uid, Result result) {
        witsystmBleSDK.getBleDevice().deletePassword(deviceId, uid, call(result));
    }

    /**
     * 通过蓝牙添加卡
     */
    private void addCard(String deviceId, String cardType, String cardName, String userId, Result result) {
        witsystmBleSDK.getBleDevice().addCard(deviceId, Enum.valueOf(CardType.class, cardType), cardName, userId, call(result));
    }


    /**
     * 取消添加卡
     */
    private void cancelAddCard(String deviceId) {
        witsystmBleSDK.getBleDevice().cancelAddCard(deviceId);
    }

    /**
     * 通过蓝牙删除卡
     */
    private void deleteCard(String deviceId, String uid, Result result) {
        witsystmBleSDK.getBleDevice().deleteCard(deviceId, uid, call(result));
    }


    /**
     * 通过蓝牙冻结卡
     */
    private void freezeCard(String deviceId, String uid, boolean isFreeze, Result result) {
        witsystmBleSDK.getBleDevice().freezeCard(deviceId, uid, isFreeze, call(result));
    }

    /**
     * 通过蓝牙关闭或者开启卡功能
     */
    private void closeOrOpenCard(String deviceId, boolean isFreeze, Result result) {
        witsystmBleSDK.getBleDevice().closeOrOpenCard(deviceId, isFreeze, call(result));
    }


    /**
     * 通过蓝牙添加指纹
     */
    private void addMark(String deviceId, String markType, String markName, String userId) {
        witsystmBleSDK.getBleDevice().addMark(deviceId, Enum.valueOf(MarkType.class, markType), markName, userId, new BleProgressCommandCall<CommandMessage>() {
            @Override
            public void progress(int sum, int value) {
                BleAddMarkResult bleAddMarkResult = new BleAddMarkResult("progress", new HashMap<String, Object>());
                bleAddMarkResult.getData().put("sum", sum);
                bleAddMarkResult.getData().put("value", value);
                handler.post(() -> bleAddMarkHandler.onProgressResult(bleAddMarkResult));
            }

            @Override
            public void sendSuccess() {
                BleAddMarkResult bleAddMarkResult = new BleAddMarkResult("sendSuccess", new HashMap<String, Object>());
                handler.post(() -> bleAddMarkHandler.onProgressResult(bleAddMarkResult));
            }

            @Override
            public void commandError(String code, String error) {
                //指令的异常，比如校验不正确
                handler.post(() -> bleAddMarkHandler.onError("commandError", code, error));
            }

            @Override
            public void fail(int code, String error) {
                handler.post(() -> bleAddMarkHandler.onError("fail", String.valueOf(code), error));
            }

            @Override
            public void success(CommandMessage message) {
                BleAddMarkResult bleAddMarkResult = new BleAddMarkResult("success", new HashMap<String, Object>());
                bleAddMarkResult.getData().put("message", message);
                handler.post(() -> bleAddMarkHandler.onProgressResult(bleAddMarkResult));
            }
        });
    }

    /**
     * 取消添加指纹
     */
    private void cancelAddMark(String deviceId) {
        witsystmBleSDK.getBleDevice().cancelAddMark(deviceId);
    }


    /**
     * 通过蓝牙删除指纹
     */
    private void deleteMark(String deviceId, String uid, Result result) {
        witsystmBleSDK.getBleDevice().deleteMark(deviceId, uid, call(result));
    }


    /**
     * 通过蓝牙冻结指纹
     */
    private void freezeMark(String deviceId, String uid, boolean isFreeze, Result result) {
        witsystmBleSDK.getBleDevice().freezeCard(deviceId, uid, isFreeze, call(result));
    }


    /**
     * 通过蓝牙添加人脸
     */
    private void addFace(String deviceId, String faceType, String markName, String userId, Result result) {
        witsystmBleSDK.getBleDevice().addFace(deviceId, Enum.valueOf(FaceType.class, faceType), markName, userId, call(result));
    }

    /**
     * 取消添加人脸
     */
    private void cancelAddFace(String deviceId) {
        witsystmBleSDK.getBleDevice().cancelAddFace(deviceId);
    }

    /**
     * 通过蓝牙删除人脸
     */
    private void deleteFace(String deviceId, String uid, Result result) {
        witsystmBleSDK.getBleDevice().deleteFace(deviceId, uid, call(result));
    }

    /**
     * 通过蓝牙冻结人脸
     */
    private void freezeFace(String deviceId, String uid, boolean isFreeze, Result result) {
        witsystmBleSDK.getBleDevice().freezeCard(deviceId, uid, isFreeze, call(result));
    }

    /**
     * 通过蓝牙修改音量
     */
    private void updateVolume(String deviceId, String volume, Result result) {
        witsystmBleSDK.getBleDevice().updateVolume(deviceId, Integer.parseInt(volume), call(result));
    }


    /**
     * 通过蓝牙同步设备状态
     */
    private void updateDeviceState(String deviceId, Result result) {
        witsystmBleSDK.getBleDevice().updateDeviceState(deviceId, call(result));
    }

    /**
     * 通过关闭指定设备的蓝牙操作
     */
    private void closeBleDevice(String deviceId) {
        witsystmBleSDK.getBleDevice().closeBleDevice(deviceId);
    }

    /**
     * 返回统一回调信息
     */
    private BleSendCommandCall<CommandMessage> call(Result result) {
        return new BleSendCommandCall<CommandMessage>() {
            @Override
            public void sendSuccess() {

            }

            @Override
            public void commandError(String code, String error) {
                result.error("COMMAND", code, error);//指令的异常，比如校验不正确
            }

            @Override
            public void fail(int code, String error) {
                result.error("DEVICE", String.valueOf(code), error);
            }

            @Override
            public void success(CommandMessage message) {
                result.success(JSON.toJSON(message));
            }
        };
    }


    /*-------------------------------- 设备的网络操作------------------------------*/


    /**
     * 返回设备列表
     */
    private void deviceList(Result result) {
        result.success(JSON.toJSONString(witsystmBleSDK.getDeviceManage().devicesList()));
    }

    /**
     * 返回指定设备的信息
     */
    private void device(String deviceId, Result result) {
        result.success(JSON.toJSONString(witsystmBleSDK.getDeviceManage().device(deviceId)));
    }

    /**
     * 获取指定设备的用户列表
     */
    private void deviceUserList(String deviceId, Result result) {
        new Thread() {
            @Override
            public void run() {
                super.run();
                NetResponse netResponse = witsystmBleSDK.getDeviceManage().deviceUserList(deviceId);
                if (netResponse.getErr() == Error.SUCCESS.getCode()) {
                    result.success(JSON.toJSONString(netResponse));
                } else {
                    result.error(String.valueOf(netResponse.getErr()), netResponse.getMsg(), netResponse.getData());
                }
            }
        }.start();
    }

    /**
     * 冻结或者解冻用户
     */
    private void freezeOrUnfreeze(String deviceId, String freezeUserUuid, boolean isFreeze, Result result) {
        new Thread() {
            @Override
            public void run() {
                super.run();
                NetResponse netResponse = witsystmBleSDK.getDeviceManage().freezeOrUnfreeze(deviceId, freezeUserUuid, isFreeze);
                if (netResponse.getErr() == Error.SUCCESS.getCode()) {
                    result.success(JSON.toJSONString(netResponse));
                } else {
                    result.error(String.valueOf(netResponse.getErr()), netResponse.getMsg(), netResponse.getData());
                }
            }
        }.start();
    }

    /**
     * 管理员或者高等级用户删除用户权限
     */
    private void manageDeleteDeviceUser(String deviceId, String deleteUserUuid, Result result) {
        new Thread() {
            @Override
            public void run() {
                super.run();
                NetResponse netResponse = witsystmBleSDK.getDeviceManage().manageDeleteDeviceUser(deviceId, deleteUserUuid);
                if (netResponse.getErr() == Error.SUCCESS.getCode()) {
                    result.success(JSON.toJSONString(netResponse));
                } else {
                    result.error(String.valueOf(netResponse.getErr()), netResponse.getMsg(), netResponse.getData());
                }
            }
        }.start();
    }

    /**
     * 发送设备
     *
     * @param deviceId   设备ID
     * @param userId     接收者账号
     * @param startDate  开始时间
     * @param endDate    结束时间
     * @param authType   权限类型
     * @param repeatType 重复类型
     */
    private void sendDevice(String userId, String deviceId, String startDate, String endDate, String authType, String repeatType, Result result) {
        new Thread() {
            @Override
            public void run() {
                super.run();
                Map<String, String> map = new HashMap<>();
                map.put("userId", userId);
                map.put("deviceId", deviceId);
                map.put("authType", authType);
                if (startDate != null) map.put("startDate", startDate);
                if (endDate != null) map.put("endDate", endDate);
                if (repeatType != null) map.put("repeatType", repeatType);

                NetResponse netResponse = witsystmBleSDK.getDeviceManage().getDeviceService().sendDevice(map);
                if (netResponse.getErr() == Error.SUCCESS.getCode()) {
                    result.success(JSON.toJSONString(netResponse));
                } else {
                    result.error(String.valueOf(netResponse.getErr()), netResponse.getMsg(), netResponse.getData());
                }
            }
        }.start();
    }

    /**
     * 转让设备
     *
     * @param deviceId 设备ID
     * @param userId   接收者账号
     */
    private void transferDevice(String userId, String deviceId, Result result) {
        new Thread() {
            @Override
            public void run() {
                super.run();
                NetResponse netResponse = witsystmBleSDK.getDeviceManage().getDeviceService().transferDevice(userId, deviceId);
                if (netResponse.getErr() == Error.SUCCESS.getCode()) {
                    result.success(JSON.toJSONString(netResponse));
                } else {
                    result.error(String.valueOf(netResponse.getErr()), netResponse.getMsg(), netResponse.getData());
                }
            }
        }.start();
    }

    /**
     * 删除设备
     *
     * @param deviceId 设备ID
     */
    private void deleteDevices(String deviceId, Result result) {
        new Thread() {
            @Override
            public void run() {
                super.run();
                NetResponse netResponse = witsystmBleSDK.getDeviceManage().getDeviceService().deleteDevices(deviceId);
                if (netResponse.getErr() == Error.SUCCESS.getCode()) {
                    result.success(JSON.toJSONString(netResponse));
                } else {
                    result.error(String.valueOf(netResponse.getErr()), netResponse.getMsg(), netResponse.getData());
                }
            }
        }.start();
    }

    /**
     * 获得开门记录
     *
     * @param deviceId 设备ID
     * @param page     第几页
     */
    private void lockRecord(String deviceId, int page, Result result) {
        new Thread() {
            @Override
            public void run() {
                super.run();
                NetResponse netResponse = witsystmBleSDK.getDeviceManage().getDeviceService().lockRecord(deviceId, page);
                if (netResponse.getErr() == Error.SUCCESS.getCode()) {
                    result.success(JSON.toJSONString(netResponse));
                } else {
                    result.error(String.valueOf(netResponse.getErr()), netResponse.getMsg(), netResponse.getData());
                }
            }
        }.start();
    }


}
