import 'package:witsystem_device_plugin/device/DeviceFunctionType.dart';

import '../WitsystemSDK.dart';
import 'dart:convert' as convert;

///设备管理

class DeviceManage extends WisystemSDk {
  factory DeviceManage() => _getInstance();

  static DeviceManage get instance => _getInstance();
  static DeviceManage? _instance;

  DeviceManage._internal();

  static DeviceManage _getInstance() {
    _instance ??= DeviceManage._internal();
    return _instance!;
  }

  /// 获得设备列表
  Future<List<dynamic>> deviceList() async {
    try {
      String json = await methodChannel.invokeMethod("deviceList");
      return Future.value(convert.json.decode(json));
    } catch (e) {
      rethrow;
    }
  }

  /// 获得指定设备的信息
  Future<Map<String, dynamic>> device(String deviceId) async {
    try {
      String json =
          await methodChannel.invokeMethod("device", {"deviceId": deviceId});
      return Future.value(convert.json.decode(json));
    } catch (e) {
      rethrow;
    }
  }

  ///查询指定设备是否  支持指定的功能或者是硬件
  Future<bool> isDeviceFunction(
      String deviceId, DeviceFunctionType type) async {
    try {
      return await methodChannel.invokeMethod(
          "isDeviceFunction", {"deviceId": deviceId, "type": type.name});
    } catch (e) {
      rethrow;
    }
  }

  ///查询指定设备的用户列表
  Future<dynamic> deviceUserList(String deviceId) async {
    try {
      String str = await methodChannel
          .invokeMethod("deviceUserList", {"deviceId": deviceId});
      var decode = convert.json.decode(str);
      return convert.json.decode(decode["data"]);
    } catch (e) {
      rethrow;
    }
  }

  ///冻结或者解冻用户
  Future<bool> freezeOrUnfreeze(
      String deviceId, String freezeUserUuid, bool isFreeze) async {
    try {
      await methodChannel.invokeMethod("freezeOrUnfreeze", {
        "deviceId": deviceId,
        "freezeUserUuid": freezeUserUuid,
        "isFreeze": isFreeze
      });
      return Future.value(true);
    } catch (e) {
      rethrow;
    }
  }

  ///管理员或者高等级用户，删除用户
  Future<bool> manageDeleteDeviceUser(
      String deviceId, String deleteUserUuid) async {
    try {
      await methodChannel.invokeMethod("manageDeleteDeviceUser",
          {"deviceId": deviceId, "deleteUserUuid": deleteUserUuid});
      return Future.value(true);
    } catch (e) {
      rethrow;
    }
  }

  ///发送设备
  Future<bool> sendDevice(String userId, String deviceId, String startDate,
      String endDate, String authType, String repeatType) async {
    try {
      await methodChannel.invokeMethod("sendDevice", {
        "userId": userId,
        "deviceId": deviceId,
        "startDate": startDate,
        "endDate": endDate,
        "authType": authType,
        "repeatType": repeatType,
      });
      return Future.value(true);
    } catch (e) {
      rethrow;
    }
  }

  ///转让设备
  Future<bool> transferDevice(String userId, String deviceId) async {
    try {
      await methodChannel.invokeMethod(
          "transferDevice", {"userId": userId, "deviceId": deviceId});
      return Future.value(true);
    } catch (e) {
      rethrow;
    }
  }

  ///删除设备
  Future<bool> deleteDevices(String deviceId) async {
    try {
      await methodChannel.invokeMethod("deleteDevices", {"deviceId": deviceId});
      return Future.value(true);
    } catch (e) {
      rethrow;
    }
  }

    ///获得开锁记录
  Future<bool> lockRecord(String deviceId,int page) async {
    try {
      await methodChannel.invokeMethod("lockRecord", {"deviceId": deviceId,"page":page});
      return Future.value(true);
    } catch (e) {
      rethrow;
    }
  }



}
